==> crawler-ninja-0.1.7.tgz: package/test/crawl-audit-mini-site-test.js <==
var assert    = require("assert");
var _         = require("underscore");
var seoaudit  = require("../plugins/audit-plugin.js");
var logger    = require("../plugins/log-plugin.js");

var testSite  = require("./website-2/start.js").site;

var crawler = require("../index.js");



describe('Audit Plugin', function() {

        it('Audit a mini site - all links images ', function(done) {

            var c = new crawler.Crawler();
            var audit = new seoaudit.Plugin(c);
            var log = new logger.Plugin(c);

            c.on("end", function() {

                //assert(audit.errors.length == 0, "Error during the crawl");

                //console.log(audit.resources.get("http://localhost:9991/index.html"));

                assert(audit.resources.get("http://localhost:9991/index.html").title =="This is the meta title of the page");
                assert(audit.resources.get("http://localhost:9991/index.html").h2.length == 3);
                assert(audit.resources.get("http://localhost:9991/index.html").contentType == "text/html; charset=UTF-8");


                assert(audit.duplicateContents.get("8d29242c03dcc5efe2c6b259bf646f6e828958d2").length == 2);

                var outLinks = audit.outLinks.get("http://localhost:9991/markdown.html");
                assert(outLinks.length == 27, "incorrect outlink, it should be : " + outLinks.length);
                assert(_.filter(outLinks,function(page){ return page.isDoFollow == false}).length == 3);

                assert(audit.inLinks.get("http://localhost:9991/markdown.html").length == 13);

                var inLinks = audit.inLinks.get("http://localhost:9991/markdown.html");
                assert(_.filter(inLinks,function(page){ return page.isDoFollow == false}).length == 0);

                //console.log(audit.resources.get("http://localhost:9991/pdf/excelforseo.pdf"));

                assert(audit.externalLinks.keys().length == 8);


                assert(audit.inLinks.get("http://localhost:9991/css/bootstrap-theme.min.css").length == 5);

                done();

            });

            c.queue({url : "http://localhost:9991/index.html"});

        });


        it('Audit a mini site - crawl only a.href links ', function(done) {

            var c = new crawler.Crawler({images : false, links: false /*links = html link tag*/, scripts:false });
            var audit = new seoaudit.Plugin(c);
            //var log = new logger.Plugin(c);

            c.on("end", function() {

                assert(audit.resources.keys().length == 10);
                done();

            });

            c.queue({url : "http://localhost:9991/index.html"});

        });

});

==> crawler-ninja-0.1.13.tgz: package/test/crawl-audit-mini-site-test.js <==
var assert    = require("assert");
var _         = require("underscore");
var seoaudit  = require("../plugins/audit-plugin.js");
var logger    = require("../plugins/log-plugin.js");

var testSite  = require("./website-2/start.js").site;

var crawler = require("../index.js");



describe('Audit Plugin', function() {

        it('Audit a mini site - all links images ', function(done) {

            var c = new crawler.Crawler();
            var audit = new seoaudit.Plugin();
            var log = new logger.Plugin();
            c.registerPlugin(audit);
            c.registerPlugin(log);

            c.on("end", function() {

                //assert(audit.errors.length == 0, "Error during the crawl");

                //console.log(audit.resources.get("http://localhost:9991/index.html"));

                assert(audit.resources.get("http://localhost:9991/index.html").title =="This is the meta title of the page");
                assert(audit.resources.get("http://localhost:9991/index.html").h2.length == 3);
                assert(audit.resources.get("http://localhost:9991/index.html").contentType == "text/html; charset=UTF-8");


                /*
                console.log(audit.duplicateContents.keys());
                audit.duplicateContents.keys().forEach(function(k){
                  console.log(audit.duplicateContents.get(k));
                });
                */
                assert(audit.duplicateContents.get("a02ecf7dbed6115812462ff0f55c5cd03bb8f3b8").length == 2);

                var outLinks = audit.outLinks.get("http://localhost:9991/markdown.html");
                assert(outLinks.length == 27, "incorrect outlink, it should be : " + outLinks.length);
                assert(_.filter(outLinks,function(page){ return page.isDoFollow == false}).length == 3);

                assert(audit.inLinks.get("http://localhost:9991/markdown.html").length == 13);

                var inLinks = audit.inLinks.get("http://localhost:9991/markdown.html");
                assert(_.filter(inLinks,function(page){ return page.isDoFollow == false}).length == 0);

                //console.log(audit.resources.get("http://localhost:9991/pdf/excelforseo.pdf"));

                assert(audit.externalLinks.keys().length == 8);


                assert(audit.inLinks.get("http://localhost:9991/css/bootstrap-theme.min.css").length == 5);

                done();

            });

            c.queue({url : "http://localhost:9991/index.html"});

        });


        it('Audit a mini site - crawl only a.href links ', function(done) {
            var c = new crawler.Crawler({images : false, links: false /*links = html link tag*/, scripts:false });
            var audit = new seoaudit.Plugin();
            //var log = new logger.Plugin();
            c.registerPlugin(audit);
            
            c.on("end", function() {
                //console.log(audit.resources.keys());
                assert(audit.resources.keys().length == 9);
                done();

            });

            c.queue({url : "http://localhost:9991/index.html"});

        });

});
